@@ -1,5 +1,5 @@
 #' @export
-"irf" <- function(x, n.ahead=24, ident="chol", shockinfo=NULL, quantiles=NULL, expert=NULL, verbose=TRUE){
+"irf" <- function(x, n.ahead=24, shockinfo=NULL, quantiles=NULL, expert=NULL, verbose=TRUE){
   UseMethod("irf", x)
 }
 
@@ -7,11 +7,10 @@
 #' @title Impulse Response Function
 #' @description This function calculates three alternative ways of dynamic responses, namely generalized impulse response functions (GIRFs) as in Pesaran and Shin (1998), orthogonalized impulse response functions using a Cholesky decomposition and finally impulse response functions given a set of user-specified sign restrictions.
 #' @export
-#' @usage irf(x, n.ahead=24, ident="chol", shockinfo=NULL, quantiles=NULL, 
+#' @usage irf(x, n.ahead=24, shockinfo=NULL, quantiles=NULL, 
 #'     expert=NULL, verbose=TRUE)
 #' @param x Object of class \code{bgvar}.
 #' @param n.ahead Forecasting horizon.
-#' @param ident Character defining type of identification scheme. Default \code{chol} refers to zero restrictions via the Cholesky decomposition while \code{sign} refers to sign-restrictions and \code{girf} to generalized impulse responses.  Details of preferred shock are given via \code{shockinfo}.
 #' @param shockinfo Dataframe with additional information about the nature of shocks. Depending on the \code{ident} argument, the dataframe has to be specified differently. In order to get a dummy version for each identification scheme use \code{\link{get_shockinfo}}.
 #' @param quantiles Numeric vector with posterior quantiles. Default is set to compute median along with 68\%/80\%/90\% confidence intervals.
 #' @param expert Expert settings, must be provided as list. Default is set to \code{NULL}.\itemize{
@@ -24,7 +23,6 @@
 #' @param verbose If set to \code{FALSE} it suppresses printing messages to the console.
 #' @return Returns a list of class \code{bgvar.irf} with the following elements: \itemize{
 #' \item{\code{posterior}}{ Four-dimensional array (K times n.ahead times number of shocks times Q) that contains Q quantiles of the posterior distribution of the impulse response functions.}
-#' \item{\code{ident}}{ Character showing the chosen identification scheme.}
 #' \item{\code{shockinfo}}{ Dataframe with details on identification specification.}
 #' \item{\code{rot.nr}}{ In case identification is based on sign restrictions (i.e., \code{ident="sign"}), this provides the number of rotation matrices found for the number of posterior draws (save*save_thin).}
 #' \item{\code{struc.obj}}{ List object that contains posterior quantitites needed when calculating historical decomposition and structural errors via \code{hd.decomp}.\itemize{
@@ -51,28 +49,35 @@
 #' oldpar <- par(no.readonly = TRUE)
 #' # First example, a US monetary policy shock, quarterly data
 #' library(BGVAR)
-#' data(eerDatasmall)
+#' data(testdata)
 #' # US monetary policy shock
-#' model.eer<-bgvar(Data=eerDatasmall, W=W.trade0012.small, draws=100, burnin=100, 
+#' model.eer<-bgvar(Data=testdata, W=W.test, draws=100, burnin=100, 
 #'                  plag=1, prior="SSVS", eigen=TRUE)
-#' 
-#' # define shock
-#' shockinfo <- get_shockinfo("chol")
-#' shockinfo$shock <- "US.stir"; shockinfo$scale <- -100
-#' 
+#'
 #' # generalized impulse responses
-#' irf.girf.us.mp<-irf(model.eer, n.ahead=20, ident="girf", shockinfo=shockinfo)
+#' shockinfo<-get_shockinfo("girf")
+#' shockinfo$shock<-"US.stir"; shockinfo$scale<--100
+#' 
+#' irf.girf.us.mp<-irf(model.eer, n.ahead=24, shockinfo=shockinfo)
 #' 
 #' # cholesky identification
-#' irf.chol.us.mp<-irf(model.eer, n.ahead=20, ident="chol", shockinfo=shockinfo)
+#' shockinfo<-get_shockinfo("chol")
+#' shockinfo$shock<-"US.stir"; shockinfo$scale<--100
 #' 
+#' irf.chol.us.mp<-irf(model.eer, n.ahead=24, shockinfo=shockinfo)
+#' # sign restrictions
+#' shockinfo <- get_shockinfo("sign")
+#' shockinfo <- add_shockinfo(shockinfo, shock="US.stir", restriction=c("US.y","US.Dp"), 
+#'                            sign=c("<","<"), horizon=c(1,1), scale=1, prob=1)
+#' irf.sign.us.mp<-irf(model.eer, n.ahead=24, shockinfo=shockinfo)
+#' 
+#' \donttest{
 #' # sign restrictions
 #' shockinfo <- get_shockinfo("sign")
 #' shockinfo <- add_shockinfo(shockinfo, shock="US.stir", restriction=c("US.y","US.Dp"), 
 #' sign=c("<","<"), horizon=c(1,1), scale=1, prob=1)
-#' irf.sign.us.mp<-irf(model.eer, n.ahead=24, ident="sign", shockinfo=shockinfo)
+#' irf.sign.us.mp<-irf(model.eer, n.ahead=24, shockinfo=shockinfo)
 #' 
-#' \donttest{
 #' #' # sign restrictions with relaxed cross-country restrictions
 #' shockinfo <- get_shockinfo("sign")
 #' # restriction for other countries holds to 75\%
@@ -80,14 +85,19 @@
 #'                            sign=c("<","<","<"), horizon=1, scale=1, prob=c(1,0.75,0.75))
 #' shockinfo <- add_shockinfo(shockinfo, shock="US.stir", restriction=c("US.Dp","EA.Dp","UK.Dp"),
 #'                            sign=c("<","<","<"), horizon=1, scale=1, prob=c(1,0.75,0.75))
-#' irf.sign.us.mp<-irf(model.eer, n.ahead=20, ident="sign", shockinfo=shockinfo)
+#' irf.sign.us.mp<-irf(model.eer, n.ahead=20, shockinfo=shockinfo)
 #' }
 #' @seealso \code{\link{bgvar}}, \code{\link{get_shockinfo}}, \code{\link{add_shockinfo}}
 #' @importFrom abind adrop abind
 #' @importFrom stochvol sv_normal sv_beta sv_gamma
 #' @importFrom RcppParallel RcppParallelLibs setThreadOptions defaultNumThreads
-irf.bgvar <- function(x,n.ahead=24,ident="chol",shockinfo=NULL,quantiles=NULL,expert=NULL,verbose=TRUE){
+irf.bgvar <- function(x,n.ahead=24,shockinfo=NULL,quantiles=NULL,expert=NULL,verbose=TRUE){
   start.irf <- Sys.time()
+  # get identification
+  ident <- attr(shockinfo, "ident")
+  if(is.null(ident)){
+    ident <- "chol"
+  }
   #--------------- checks ------------------------------------------------------------------------------------#
   if(!ident%in%c("chol","girf","sign")){
     stop("Please choose available identification scheme!")
@@ -603,11 +613,18 @@ print.bgvar.irf <- function(x, ...){
 #' @seealso \code{\link{irf}}
 #' @export
 get_shockinfo <- function(ident="chol", nr_rows=1){
-  if(ident=="chol" || ident=="girf")
-    return(data.frame(shock=rep(NA,nr_rows),scale=rep(1,nr_rows),global=rep(FALSE,nr_rows)))
-  if(ident=="sign")
-  return(data.frame(shock=rep(NA,nr_rows),restriction=rep(NA,nr_rows),sign=rep(NA,nr_rows),
-                    horizon=rep(NA,nr_rows),scale=rep(NA,nr_rows),prob=rep(NA,nr_rows),global=rep(NA,nr_rows)))
+  if(ident == "chol"){
+    df <- data.frame(shock=rep(NA,nr_rows),scale=rep(1,nr_rows),global=rep(FALSE,nr_rows))
+    attr(df, "ident") <- "chol"
+  }else if(ident == "girf"){
+    df <- data.frame(shock=rep(NA,nr_rows),scale=rep(1,nr_rows),global=rep(FALSE,nr_rows))
+    attr(df, "ident") <- "girf"
+  }else if(ident=="sign"){
+    df <- data.frame(shock=rep(NA,nr_rows),restriction=rep(NA,nr_rows),sign=rep(NA,nr_rows),
+                     horizon=rep(NA,nr_rows),scale=rep(NA,nr_rows),prob=rep(NA,nr_rows),global=rep(NA,nr_rows))
+    attr(df, "ident") <- "sign"
+  }
+  return(df)
 }
 
 #' @name add_shockinfo
